@@ -15,13 +15,14 @@ class KMSGrant(Generic, EncryptableResource):
     def pre_render(self, service):
         if service.plugins.get(IAMRoles):
             for fn in service.functions.all():
-                service.custom["kmsGrants"].append(dict(
-                    kmsKeyId=self.encryption_key().to_dict(),
-                    lambdaRoleArn=fn.iam.role_arn
-                ))
+                service.custom["kmsGrants"].append(
+                    dict(
+                        kmsKeyId="alias/${self:service}-${sls:stage}",
+                        roleName=fn.iam.role,
+                    )
+                )
 
         else:
-            service.custom["kmsGrants"].append(dict(
-                kmsKeyId=self.encryption_key().to_dict(),
-                lambdaRoleArn=service.provider.iam.role_arn
-            ))
+            service.custom["kmsGrants"].append(
+                dict(kmsKeyId=self.encryption_key().to_dict(), roleName=service.provider.iam.role)
+            )
